declare namespace StringSplitter {
    interface Chunk {
        key: string;
        text: string;
        match: boolean;
    }
    interface Splitter {
        text: string;
        query: string;
        pad?: number;
        fuzy?: boolean;
    }
    interface Clip {
        curr: Chunk;
        next: Chunk;
        prev: Chunk;
        pad?: number;
    }
    interface Query {
        terms: string;
        fuzy?: boolean;
    }
}
export { StringSplitter };
/**
 * Split a text into chunks denoting which are a match and which are not based on a user search term.
 * @param text  String  The text to split.
 * @param query String  The query to split by. This can contain multiple words.
 * @param pad   Number  Clip the non-matches by a certain number of words to provide context around the matches.
 * @param exact Boolean If we have multiple words in the query, we will match any of the words if exact is false. For example, searching for "brown fox" in "the brown cute fox" will yield both "brown" and "fox" as matches. While if exact is true, the same search will return no results.
 */
declare const splitString: ({ text, query, pad, fuzy }: StringSplitter.Splitter) => StringSplitter.Chunk[];
export default splitString;
